starcluster.webtools

Package starcluster :: Module webtools |
[hide private]
[frames] | no frames]

# Module webtools

source code

Classes | [hide private]
| StoppableHttpServer http server that reacts to self.stop flag
| BaseHandler
| DocrootHandler
| TemplateHandler Simple GET handler that loads and renders files/templates within a package under the starcluster.templates package.
| BackgroundBrowser Class for all browsers which are to be started in the background.

Functions | [hide private]
get_template_server(root_template_pkg=`'``/``'`, interface=`'``localhost``'`, port=None, context=`{``}`) | source code
get_webserver(interface=`'``localhost``'`, port=None, handler=<class starcluster.webtools.DocrootHandler at 0x24c70b0>) | source code
_is_exe(fpath) | source code
_which(program) | source code
open_browser(url, browser_cmd=None) | source code
main(path, interface=`'``localhost``'`, port=8080) | source code

Variables | [hide private]
| ERROR_MSG = ``'``<head>\n<title>DOH!</title>\n</head>\n<body>\n<pr``...``
| __package__ = ``'``starcluster``'``

Variables Details | [hide private]

  ### ERROR_MSG Value:
      '''<head>
      <title>DOH!</title>
      </head>
      <body>
      <pre>
       _  _    ___  _  _
      | || |  / _ \\| || |
      | || |_| | | | || |_
      ...